
# Slot: molecular_function

The molecular function that is carried out by the gene product or complex

URI: [gocam:activity__molecular_function](https://w3id.org/gocam/activity__molecular_function)


## Domain and Range

None &#8594;  <sub>0..1</sub> [MolecularFunctionAssociation](MolecularFunctionAssociation.md)

## Parents


## Children


## Used by

 * [Activity](Activity.md)
